/***************************************************************************
                          knightstextview.h  -  description
                             -------------------
    begin                : Sun Dec 16 2001
    copyright            : (C) 2003 by Troy Corbin Jr.
    email                : tcorbin@users.sourceforge.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KNIGHTSTEXTVIEW_H
#define KNIGHTSTEXTVIEW_H

#include <tqwidget.h>
#include <tqtextbrowser.h>

/**
  *@author Troy Corbin Jr./Alexander Wels
  */

class TDEPopupMenu;
class resource;

class KnightsTextView : public TQTextBrowser
{
   TQ_OBJECT
  
	public:
										KnightsTextView(TQWidget *parent, resource *Rsrc );
										~KnightsTextView();
		void						pageMove( TQt::Key key=Key_PageUp );

	public slots:
		void						display_menuView( const TQPoint& );
		void						menuFunct( int );
		void						displayLink(const TQString& urlString);
		void						print( void );

	signals:
		void						rightButtonClicked( const TQPoint& );

	protected:
		void						viewportMousePressEvent( TQMouseEvent *e );
		resource				*myResource;
		TDEPopupMenu			*menuView;
};

#endif
